// src/api/attachInterceptors.js
import { refreshAccessToken } from './tokenUtils';

export const attachAuthInterceptors = (axiosInstance, logout) => {
  axiosInstance.interceptors.request.use(config => {
    const token = localStorage.getItem('access');
    if (token) {
      config.headers.Authorization = `Bearer ${token}`;
    }
    return config;
  });

  axiosInstance.interceptors.response.use(
    res => res,
    async err => {
      const originalRequest = err.config;

      if (
        err.response?.status === 401 &&
        !originalRequest._retry &&
        localStorage.getItem('refresh')
      ) {
        originalRequest._retry = true;

        try {
          const newAccess = await refreshAccessToken();
          originalRequest.headers.Authorization = `Bearer ${newAccess}`;
          return axiosInstance(originalRequest);
        } catch (refreshError) {
          console.error('토큰 갱신 실패', refreshError);
          if (logout) logout(); // ✅ Context logout 반영
          window.location.href = '/login';
        }
      }

      return Promise.reject(err);
    }
  );
};
