// src/api/boardApi.js
import axios from 'axios';
import { attachAuthInterceptors } from './attachInterceptors';

const boardApi = axios.create({
  baseURL: process.env.REACT_APP_API_BOARD, // ex) http://localhost:8801/api
  headers: {
    'Content-Type': 'application/json',
  },
});

// JWT 인증 토큰 인터셉터 부착
attachAuthInterceptors(boardApi);

// ✅ 게시판 목록 조회
export const fetchBoards = () => boardApi.get('/api/boards/');

// ✅ 특정 게시판의 게시글 목록 조회
export const fetchPosts = (boardSlug, params = {}) =>
  boardApi.get(`/api/boards/${boardSlug}/posts/`, { params });

// ✅ 특정 게시글 상세 조회
export const fetchPostDetail = (boardSlug, postId) =>
  boardApi.get(`/api/boards/${boardSlug}/posts/${postId}/`);

// ✅ 게시글 생성
export const createPost = (boardSlug, data) =>
  boardApi.post(`/api/boards/${boardSlug}/posts/`, data);

// ✅ 게시글 수정
export const updatePost = (boardSlug, postId, data) =>
  boardApi.put(`/api/boards/${boardSlug}/posts/${postId}/`, data);

// ✅ 게시글 삭제
export const deletePost = (boardSlug, postId) =>
  boardApi.delete(`/api/boards/${boardSlug}/posts/${postId}/`);

export default boardApi;
