// src/components/Board/PostList.js
import React, { useEffect, useState } from "react";
import { fetchPosts } from "../../api/boardApi";

const PostList = ({ boardSlug, search, tag }) => {
  const [posts, setPosts] = useState([]);

  useEffect(() => {
    if (!boardSlug) return;

    const loadPosts = async () => {
      try {
        const params = {};
        if (tag) params.tag = tag;
        if (search) params.search = search;

        const res = await fetchPosts(boardSlug, params);
        setPosts(res.data);
      } catch (err) {
        console.error("❌ 게시글 목록 불러오기 실패", err);
      }
    };

    loadPosts();
  }, [boardSlug, search, tag]);

  if (!boardSlug) return <p>📂 게시판을 선택해주세요.</p>;

  return (
    <div>
      <h2 className="text-lg font-bold mb-2">📝 게시글 목록</h2>
      <ul className="space-y-2">
        {posts.map((post) => (
          <li key={post.id} className="border p-2 rounded shadow">
            <h3 className="font-semibold">{post.title}</h3>
            <p className="text-sm text-gray-500">작성자: {post.author_name}</p>
            <p className="text-gray-700 line-clamp-2">{post.content}</p>
          </li>
        ))}
      </ul>
    </div>
  );
};

export default PostList;
