import React from "react";
import { Link, useNavigate, useLocation } from "react-router-dom";
import { useAuth } from "../context/AuthContext";

const Navbar = () => {
  const navigate = useNavigate();
  const location = useLocation();
  const { isLoggedIn, logout, user } = useAuth();

  const isHome = location.pathname === "/";

  const menuItems = [
    { name: "home", path: "/" },
    { name: "about", path: "/about" },
    { name: "posts", path: "/posts" },
    { name: "boards", path: "/boards" },
    ...(isLoggedIn ? [
      { name: "tasks", path: "/tasks" },
      { name: "ansible", path: "/ansible" },
    ] : []),
  ];

  return (
    <nav className={`fixed top-0 w-full z-50 h-16 ${isHome ? "text-white bg-transparent" : "text-black bg-white shadow"}`}>
      <div className="container mx-auto px-4 py-3 flex justify-between items-center">
        <Link to="/" className="text-xl font-bold tracking-wide">
          ICURFER
        </Link>
        <div className="hidden md:flex space-x-6 font-semibold">
          {menuItems.map((item) => (
            <Link
              key={item.name}
              to={item.path}
              className={`hover:text-yellow-400 transition capitalize`}
            >
              {item.name}
            </Link>
          ))}
        </div>
        <div className="space-x-2 flex items-center ">
          {isLoggedIn ? (
            <>
              <Link
                to="/profile"
                className={`px-4 py-2 rounded-full shadow ${isHome ? "bg-white text-black" : "bg-gray-200 text-gray-800"}`}
              >
                내 정보 | 등급: {user?.grade && `(${user.grade})`}
              </Link>
              <button
                onClick={() => {
                  logout();
                  navigate("/login");
                }}
                className={`px-4 py-2 rounded-full ${isHome ? "bg-white text-black" : "bg-gray-200 text-gray-800"} hover:bg-gray-300`}
              >
                로그아웃
              </button>
            </>
          ) : (
            <>
              <Link
                to="/login"
                className={`px-4 py-2 rounded-full ${isHome ? "bg-gray-200 text-gray-700 hover:bg-gray-300" : "bg-blue-600 text-white"}`}
              >
                로그인
              </Link>
              <Link
                to="/register"
                className={`px-4 py-2 rounded-full ${isHome ? "bg-gray-700 text-white hover:bg-gray-300" : "bg-gray-200 text-gray-800"}`}
              >
                회원가입
              </Link>
            </>
          )}
        </div>
      </div>
    </nav>
  );
};

export default Navbar;
