import React, { useEffect, useState } from 'react';
import blogApi from '../api/blogApi';
import { useNavigate } from 'react-router-dom';

const Home = () => {
  const [posts, setPosts] = useState([]);
  const navigate = useNavigate();

  useEffect(() => {
    blogApi.get('/api/blog/posts/')
      .then(res => setPosts(res.data))
      .catch(err => console.error('게시글 목록 조회 실패:', err));
  }, []);

  return (
    <div className="min-h-screen">
      <div className="relative h-screen">
        <div className="absolute inset-0">
          <img
            src="/bg.png"
            className="w-full h-full object-cover"
            // className="w-full h-full object-cover"
            alt="Hero Background"
          />
        </div>
        <div className="absolute inset-0 bg-gradient-to-r from-black/70 to-transparent">
          <div className="container mx-auto px-4 h-full flex items-center">
            <div className="max-w-2xl text-white">
              <h1 className="text-5xl font-bold mb-6">System Management Portal</h1>
              <p className="text-xl mb-8">데모 사이트 입니다.</p>
              <button className="bg-[#3B82F6] text-white px-8 py-3 rounded-lg">개발 중 입니다.</button>
            </div>
          </div>
        </div>
      </div>

      <div className="container mx-auto px-4 py-20">
        <h2 className="text-3xl font-bold mb-12 text-center">최신 포스트</h2>
        <ul className="grid grid-cols-1 md:grid-cols-3 gap-8">
          {posts.length > 0 ? (
            posts.map(post => (
              <li
                key={post.id}
                className="p-4 border rounded shadow-sm bg-white hover:bg-gray-50 cursor-pointer list-none"
                onClick={() => navigate(`/posts/${post.id}`)}
              >
                <h2 className="text-xl font-semibold">{post.title}</h2>
                <p className="text-gray-600">작성자: {post.author_name}</p>
                <p className="text-gray-400 text-sm">
                  작성일: {new Date(post.created_at).toLocaleString()}
                </p>
              </li>
            ))
          ) : (
            <p className="text-center col-span-3 text-gray-500">게시글이 없습니다.</p>
          )}
        </ul>
      </div>
    </div>
  );
};

export default Home;
